@@ -1,7 +1,9 @@
 from collections import namedtuple
 from urllib.parse import urlparse
+
 from tinybird_cdk import errors
-from . import s3, gcs
+
+from . import gcs, s3
 
 # Public interface for cloud service names. Please, do not hardcode or rely on
 # the values stored in these constants outside of this file.
@@ -19,7 +21,7 @@ ParsedURL = namedtuple("ParsedURL", "service bucket key")
 #   * `key` is either a non-empty string or `None`. Non-empty strings have no
 #     leading or trailing slashes even if they had them in the original URL.
 #
-# If the service is unknown, `errors.UnsupportedCloudServiceScheme` is raised.
+# If the service is unknown, `errors.UnsupportedCloudServiceSchemeError` is raised.
 def parse_url(url):
     parsed = urlparse(url)
     service = _service_for(parsed.scheme)
@@ -30,13 +32,13 @@ def parse_url(url):
 def client_for(service):
     if service == 'S3':
         return s3.Client()
-    elif service == 'GCS':
+    if service == 'GCS':
         return gcs.Client()
-    raise errors.UnsupportedCloudService(service)
+    raise errors.UnsupportedCloudServiceError(service)
 
 def _service_for(scheme):
     if scheme == 's3':
         return S3
-    elif scheme in ('gs', 'gcs'):
+    if scheme in ('gs', 'gcs'):
         return GCS
-    raise errors.UnsupportedCloudServiceScheme(scheme)
+    raise errors.UnsupportedCloudServiceSchemeError(scheme)
