@@ -1,14 +1,23 @@
 import csv
 import tempfile
 from abc import ABC, abstractmethod
-from collections import namedtuple
+from dataclasses import dataclass
+from typing import Optional
 
 import ndjson
 
 from . import errors, logger, tinybird
 from .export import URL, CloudDir, CloudFile, Data, LocalFile
 
-Scope = namedtuple('Scope', 'name value')
+@dataclass(frozen=True)
+class Scope:
+    name: str
+    value: str
+
+@dataclass(frozen=True)
+class Table(Scope):
+    num_rows: Optional[int]=None
+    size: Optional[int]=None
 
 class Connector:
     '''
