@@ -57,7 +57,10 @@ class Connector(connector.SQLConnector):
     def _list_tables(self, project, dataset):
         tables = []
         for table in list(self.bigquery.list_tables(dataset=f'{project}.{dataset}')):
-            tables.append(connector.Scope(name=table.table_id, value=table.table_id))
+            table_info = self.bigquery.get_table(table.reference)
+            tables.append(connector.Table(
+                name=table.table_id, value=table.table_id, num_rows=table_info.num_rows, size=table_info.num_bytes
+            ))
         tables.sort(key=lambda table: table.name)
         return tables
 
