@@ -1,19 +1,23 @@
 import sqlite3
-from tinybird_cdk import config, connector, export, formats, errors
 
+from tinybird_cdk import config, connector, errors, export, formats
+
+
+# WARNING: THIS CONNECTOR WAS JUST PROTOTYPED TO HELP DESIGN THE CDK, BUT IT IS
+# NOT USED AND IT DOES NOT HAVE TESTS.
 class Connector(connector.SQLConnector):
     def __init__(self):
         super().__init__()
         self.database = config.get('SQLITE_DATABASE')
 
     def get_scopes(self):
-        raise 'Not implemented'
+        raise Exception('Not implemented')
 
     def list_scope(self, _parents={}):
-        raise 'Not implemented'
+        raise Exception('Not implemented')
 
-    def suggest_schema(self, parents):
-        raise 'Not implemented'
+    def suggest_schema(self, _scopes):
+        raise Exception('Not implemented')
 
     def _query(self, sql):
         with sqlite3.connect(self.database) as conn:
@@ -36,6 +40,6 @@ class Connector(connector.SQLConnector):
                 # dictionary because rows themselves are not serializable.
                 fname = self._to_ndjson_tempfile((dict(row) for row in cursor))
             else:
-                raise errors.UnsupportedFormat(fmt)
+                raise errors.UnsupportedFormatError(fmt)
 
         return export.LocalFile(fname)
